from typing import List

from typing import overload
import _pysiclib.linalg

def find_kurtosis(arg0: _pysiclib.linalg.Tensor, arg1: int) -> _pysiclib.linalg.Tensor: ...
def find_mean(arg0: _pysiclib.linalg.Tensor, arg1: int) -> _pysiclib.linalg.Tensor: ...
def find_moment(arg0: _pysiclib.linalg.Tensor, arg1: int, arg2: int, arg3: bool, arg4: bool) -> _pysiclib.linalg.Tensor: ...
def find_skew(arg0: _pysiclib.linalg.Tensor, arg1: int) -> _pysiclib.linalg.Tensor: ...
def find_stddev(arg0: _pysiclib.linalg.Tensor, arg1: int) -> _pysiclib.linalg.Tensor: ...
def find_variance(arg0: _pysiclib.linalg.Tensor, arg1: int) -> _pysiclib.linalg.Tensor: ...
@overload
def rand_normal_tensor(arg0: float, arg1: float, arg2: List[int]) -> _pysiclib.linalg.Tensor: ...
@overload
def rand_normal_tensor(arg0: float, arg1: float, arg2: List[int]) -> _pysiclib.linalg.Tensor: ...



from .._pysiclib import numerical as _impl_numerical
from .._pysiclib.numerical import *

#differentiation

#intial value
def initial_value_problem(
	system_of_eqs,
	inital_conditions,
	target_value,
	initial_value = 0.0):

	return _impl_numerical.initial_value_problem(
		system_of_eqs,
		inital_conditions,
		target_value,
		initial_value
	)

#integration
def integral_index_interval(
	input_array, start_index = 0, end_index = None):
	if end_index == None:
		end_index = len(input_array)
	return _impl_numerical.integral_index_interval(
		input_array, start_index, end_index)

#sol equations
def equation_solution(equation_as_function, target_val, precision = 6):
	output_val =\
		_impl_numerical.equation_solution(equation_as_function, target_val)
	if (output_val == None):
		 return None
	else:
		return round(output_val, precision)



from .._pysiclib.numerical import *
from typing import Any

def initial_value_problem(system_of_eqs, inital_conditions, target_value, initial_value: float = ...): ...
def integral_index_interval(input_array, start_index: int = ..., end_index: Any | None = ...): ...
def equation_solution(equation_as_function, target_val, precision: int = ...): ...



from typing import Callable, List

from typing import overload
import numpy

class Tensor:
    @overload
    def __init__(self, numpy_array: numpy.ndarray[numpy.float64]) -> None: ...
    @overload
    def __init__(self, input_data: List[float], input_shape: List[int] = ..., input_stride: List[int] = ..., offset: int = ...) -> None: ...
    @overload
    def __init__(self, other_view: Tensor) -> None: ...
    def binary_element_wise_op(self, arg0: Tensor, arg1: Callable[[float,float],float]) -> Tensor: ...
    def deep_copy(self) -> Tensor: ...
    def fold_op(self, arg0: Callable[[float,float],float], arg1: float, arg2: int, arg3: bool) -> Tensor: ...
    def get_buffer(self) -> List[float]: ...
    def get_offset(self) -> int: ...
    def get_shape(self) -> List[int]: ...
    def get_stride(self) -> List[int]: ...
    def matmul(self, arg0: Tensor) -> Tensor: ...
    def slice_view(self, arg0: List[int]) -> Tensor: ...
    def squeeze(self, target_dim: int = ...) -> Tensor: ...
    def to_numpy(self) -> numpy.ndarray[numpy.float64]: ...
    def transpose(self, dim_1: int = ..., dim_2: int = ...) -> Tensor: ...
    def unitary_op(self, arg0: Callable[[float],float]) -> Tensor: ...
    def unsqueeze(self, arg0: int) -> Tensor: ...



from typing import Callable, List

import _pysiclib.linalg

class ProtoNet:
    def __init__(self, arg0: int, arg1: int, arg2: int, arg3: int, arg4: float) -> None: ...
    def query_net(self, arg0: _pysiclib.linalg.Tensor) -> _pysiclib.linalg.Tensor: ...
    def run_epoch(self, arg0: _pysiclib.linalg.Tensor, arg1: _pysiclib.linalg.Tensor) -> None: ...
    @property
    def m_bias(self) -> List[_pysiclib.linalg.Tensor]: ...
    @property
    def m_transform(self) -> Callable[[float],float]: ...
    @property
    def m_transform_deriv(self) -> Callable[[float],float]: ...
    @property
    def m_weights(self) -> List[_pysiclib.linalg.Tensor]: ...



from typing import Any, Callable, Optional

def derivative_at_index(arg0, arg1: int) -> float: ...
def equation_solution(arg0: Callable[[float],float], arg1: float) -> Optional[float]: ...
def initial_value_problem(*args, **kwargs) -> Any: ...
def integral_index_interval(arg0, arg1: int, arg2: int) -> float: ...
